pub enum StretchPolicy {
TempoRatio(Time),
TimeRatio(Time),
FitToDuration(Time),
TimeMap(Vec<TimeMapPoint>),
WarpMarkers(Vec<WarpMarker>),
}Expand description
Strategy for stretching or warping material along the time axis.
Variants
TempoRatio(Time)
Scale time inversely to a tempo ratio (faster tempo, shorter time).
TimeRatio(Time)
Scale time directly by a time ratio.
FitToDuration(Time)
Scale time so the material fills a target duration.
TimeMap(Vec<TimeMapPoint>)
Warp time through an explicit piecewise-linear map.
WarpMarkers(Vec<WarpMarker>)
Warp time through a set of WarpMarker anchors.
Implementations
Sourceimpl StretchPolicy
impl StretchPolicy
Sourcepub fn apply(&self, object: &dyn MusicObject) -> Result<Music, TransformError>
pub fn apply(&self, object: &dyn MusicObject) -> Result<Music, TransformError>
Applies the stretch and returns just the music.
Sourcepub fn apply_report(
&self,
object: &dyn MusicObject,
) -> Result<TransformReport, TransformError>
pub fn apply_report( &self, object: &dyn MusicObject, ) -> Result<TransformReport, TransformError>
Applies the stretch, returning the music and any diagnostics.