pub fn apply_serial_row_operation(
realization: &SerialRealization,
operation: RowOperation,
) -> Result<SerialStaffTransform, TransformError>Expand description
Applies a total row operation to the realized pitches and time order.
pub fn apply_serial_row_operation(
realization: &SerialRealization,
operation: RowOperation,
) -> Result<SerialStaffTransform, TransformError>Applies a total row operation to the realized pitches and time order.