pub fn loop_n(
object: &dyn MusicObject,
n: usize,
) -> Result<Music, TransformError>Expand description
Repeats the material n times back to back along the time axis.
pub fn loop_n(
object: &dyn MusicObject,
n: usize,
) -> Result<Music, TransformError>Repeats the material n times back to back along the time axis.