map_to_function

Function map_to_function 

pub fn map_to_function(
    object: &dyn MusicObject,
    key: &Key,
    fmap: &FunctionMap,
) -> Result<Music, TransformError>
Remaps each in-key note to the same scale degree under another function.

Notes whose pitch class is not a degree of key are passed through.