pub fn quantize_serial(
realization: &SerialRealization,
grid: Time,
) -> Result<SerialStaffTransform, TransformError>Expand description
Quantizes only when the result is already exact on the requested grid; otherwise fails closed.
pub fn quantize_serial(
realization: &SerialRealization,
grid: Time,
) -> Result<SerialStaffTransform, TransformError>Quantizes only when the result is already exact on the requested grid; otherwise fails closed.