pub fn retrograde(object: &dyn MusicObject) -> Result<Music, TransformError>Expand description
Reverses the material in time using the default RetrogradeMode::Cutout.
pub fn retrograde(object: &dyn MusicObject) -> Result<Music, TransformError>Reverses the material in time using the default RetrogradeMode::Cutout.