pub fn shift_octave(
object: &dyn MusicObject,
octaves: i16,
) -> Result<Music, TransformError>Expand description
Shifts every note by the given number of whole octaves.
pub fn shift_octave(
object: &dyn MusicObject,
octaves: i16,
) -> Result<Music, TransformError>Shifts every note by the given number of whole octaves.