pub fn time_invert(object: &dyn MusicObject) -> Result<Music, TransformError>Expand description
Mirrors note onsets about the total duration, then rebases to start at zero.
pub fn time_invert(object: &dyn MusicObject) -> Result<Music, TransformError>Mirrors note onsets about the total duration, then rebases to start at zero.