pub struct ExactVoicing {
pub at: Time,
pub notes: Vec<ExactVoiceNote>,
}Expand description
Exact sounding notes at one score boundary.
Fields
at: TimeBoundary in exact whole-note time.
notes: Vec<ExactVoiceNote>Notes sorted by pitch, then voice and event identity.
Implementations
Sourceimpl ExactVoicing
impl ExactVoicing
Sourcepub fn from_staff(staff: &Staff, at: Time) -> Result<Self, TransformError>
pub fn from_staff(staff: &Staff, at: Time) -> Result<Self, TransformError>
Reads all notes sounding at at from an identity-bearing staff.
Half-open note spans are used: an event is sounding exactly when
onset <= at < end.