pub struct VoiceLeadingPolicy {
pub entrance_cost: i64,
pub departure_cost: i64,
pub doubling_cost: Option<i64>,
pub voice_crossing: VoiceCrossingPolicy,
pub metric: VoiceLeadingMetric,
}Expand description
Explicit costs and structural policy for exact voice leading.
Fields
entrance_cost: i64Cost of a target voice entering without a source.
departure_cost: i64Cost of a source voice leaving without a target.
doubling_cost: Option<i64>Incremental cost for a source supplying an additional target.
voice_crossing: VoiceCrossingPolicyWhether the pitch-sorted voices may cross.
metric: VoiceLeadingMetricMotion norm.
Implementations
Sourceimpl VoiceLeadingPolicy
impl VoiceLeadingPolicy
Sourcepub fn new(entrance_cost: i64, departure_cost: i64) -> Self
pub fn new(entrance_cost: i64, departure_cost: i64) -> Self
Builds a squared-distance policy with no doubling and crossings allowed.
Sourcepub fn with_doubling(self, cost: i64) -> Self
pub fn with_doubling(self, cost: i64) -> Self
Enables source doubling at the supplied incremental cost.
Sourcepub fn with_voice_crossing(self, policy: VoiceCrossingPolicy) -> Self
pub fn with_voice_crossing(self, policy: VoiceCrossingPolicy) -> Self
Sets the voice-crossing policy.
Sourcepub fn with_metric(self, metric: VoiceLeadingMetric) -> Self
pub fn with_metric(self, metric: VoiceLeadingMetric) -> Self
Sets the motion norm.