pub struct VoicingChangePalette {
pub voicings: Vec<ExactVoicing>,
pub changes: Vec<VoicingChange>,
}Expand description
All directed transitions among a finite exact voicing palette.
Fields
voicings: Vec<ExactVoicing>Palette voicings.
changes: Vec<VoicingChange>Unique directed changes in (source, target) order.
Implementations
Sourceimpl VoicingChangePalette
impl VoicingChangePalette
Sourcepub fn outgoing(&self, source: usize) -> impl Iterator<Item = &VoicingChange>
pub fn outgoing(&self, source: usize) -> impl Iterator<Item = &VoicingChange>
Returns all changes leaving source, or an empty slice iterator for a
dead end.