pub fn loop_n(object: &dyn MusicObject, n: usize) -> MusicExpand description
Repeats the material n times back to back along the time axis.
pub fn loop_n(object: &dyn MusicObject, n: usize) -> MusicRepeats the material n times back to back along the time axis.