pub fn progression_overlay(
progressions: &[Staff],
) -> Result<MusicTransform<Staff>, TransformError>Expand description
Overlays exact progressions at the same origin.
The input identity sets must be disjoint except that equal voice ids with equal names may be merged. Reusing a note or event id fails closed.