pub fn shift_octave(object: &dyn MusicObject, octaves: i16) -> MusicExpand description
Shifts every note by the given number of whole octaves.
pub fn shift_octave(object: &dyn MusicObject, octaves: i16) -> MusicShifts every note by the given number of whole octaves.