pub fn time_invert(object: &dyn MusicObject) -> MusicExpand description
Mirrors note onsets about the total duration, then rebases to start at zero.
pub fn time_invert(object: &dyn MusicObject) -> MusicMirrors note onsets about the total duration, then rebases to start at zero.